# Generated by roxygen2: do not edit by hand

S3method(parse_all,"function")
S3method(parse_all,call)
S3method(parse_all,character)
S3method(parse_all,connection)
S3method(parse_all,default)
S3method(replay,character)
S3method(replay,default)
S3method(replay,error)
S3method(replay,list)
S3method(replay,message)
S3method(replay,recordedplot)
S3method(replay,source)
S3method(replay,value)
S3method(replay,warning)
export(create_traceback)
export(evaluate)
export(flush_console)
export(inject_funs)
export(is.error)
export(is.message)
export(is.recordedplot)
export(is.source)
export(is.value)
export(is.warning)
export(new_output_handler)
export(parse_all)
export(remove_hooks)
export(replay)
export(set_hooks)
export(try_capture_stack)
import(grDevices)
import(graphics)
import(utils)
