# Evaluator

The evaluator classes for automatic evaluation.

## Evaluator classes

The main entry point for using the evaluator:

[[autodoc]] evaluate.evaluator

The base class for all evaluator classes:

[[autodoc]] evaluate.Evaluator

## The task specific evaluators

### ImageClassificationEvaluator

[[autodoc]] evaluate.ImageClassificationEvaluator

### QuestionAnsweringEvaluator

[[autodoc]] evaluate.QuestionAnsweringEvaluator
    - compute

### TextClassificationEvaluator

[[autodoc]] evaluate.TextClassificationEvaluator

### TokenClassificationEvaluator

[[autodoc]] evaluate.TokenClassificationEvaluator
    - compute

### TextGenerationEvaluator

[[autodoc]] evaluate.TextGenerationEvaluator
    - compute

### Text2TextGenerationEvaluator

[[autodoc]] evaluate.Text2TextGenerationEvaluator
    - compute

### SummarizationEvaluator

[[autodoc]] evaluate.SummarizationEvaluator
    - compute

### TranslationEvaluator

[[autodoc]] evaluate.TranslationEvaluator
    - compute

### AutomaticSpeechRecognitionEvaluator

[[autodoc]] evaluate.AutomaticSpeechRecognitionEvaluator
    - compute

### AudioClassificationEvaluator

[[autodoc]] evaluate.AudioClassificationEvaluator
    - compute