% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/output.r
\name{is.message}
\alias{is.message}
\alias{is.warning}
\alias{is.error}
\alias{is.value}
\alias{is.source}
\alias{is.recordedplot}
\title{Object class tests}
\usage{
is.message(x)

is.warning(x)

is.error(x)

is.value(x)

is.source(x)

is.recordedplot(x)
}
\description{
Object class tests
}
\keyword{internal}
